diff --git a/intro.cabal b/intro.cabal
--- a/intro.cabal
+++ b/intro.cabal
@@ -1,6 +1,6 @@
 cabal-version: 1.12
 name:           intro
-version:        0.7.0.0
+version:        0.8.0.0
 synopsis:       Safe and minimal prelude
 description:    Intro is a modern Prelude which provides safe alternatives
                 for most of the partial functions and follows other
@@ -44,8 +44,6 @@
       base >=4.8 && <5.0
     , bytestring >=0.9 && <0.11
     , containers >=0.5 && <0.7
-    , deepseq >=1.4 && <1.5
-    , dlist >=0.7 && <0.9
     , extra >=1.5.1 && <2.0
     , hashable >=1.2.5 && <2.0
     , mtl >=2.2 && <2.3
@@ -71,8 +69,6 @@
     , base
     , bytestring
     , containers
-    , deepseq
-    , dlist
     , extra
     , hashable
     , intro
diff --git a/src/Intro/ConvertString.hs b/src/Intro/ConvertString.hs
--- a/src/Intro/ConvertString.hs
+++ b/src/Intro/ConvertString.hs
@@ -28,7 +28,6 @@
   , Lenient(..)
 ) where
 
-import Control.DeepSeq (NFData)
 import Data.ByteString (ByteString)
 import Data.ByteString.Short (ShortByteString)
 import Data.Either.Extra (eitherToMaybe)
@@ -95,8 +94,6 @@
 -- | Newtype wrapper for a string which was decoded leniently.
 newtype Lenient a = Lenient { getLenient :: a }
   deriving (Eq, Ord, Read, Show, Functor, Foldable, Traversable, Generic, Generic1)
-
-instance NFData a => NFData (Lenient a)
 
 instance ConvertString BL.ByteString   (Lenient String)  where {-# INLINE convertString #-}; convertString = Lenient . TL.unpack . TLE.decodeUtf8With lenientDecode
 instance ConvertString BL.ByteString   (Lenient TL.Text) where {-# INLINE convertString #-}; convertString = Lenient . TLE.decodeUtf8With lenientDecode
diff --git a/src/Intro/Trustworthy.hs b/src/Intro/Trustworthy.hs
--- a/src/Intro/Trustworthy.hs
+++ b/src/Intro/Trustworthy.hs
@@ -18,8 +18,7 @@
 -----------------------------------------------------------------------------
 
 module Intro.Trustworthy (
-  Data.DList.DList
-  , GHC.Exts.IsList(
+  GHC.Exts.IsList(
       Item
       , fromList
       , toList
@@ -41,7 +40,6 @@
 import Data.Function ((.))
 import Data.Text (Text, unpack)
 import Text.Show (Show)
-import qualified Data.DList
 import qualified Debug.Trace
 import qualified GHC.Exts
 import qualified Data.Hashable.Lifted

diff --git a/src/Intro.hs b/src/Intro.hs
--- a/src/Intro.hs
+++ b/src/Intro.hs
@@ -82,8 +82,9 @@
 -- * 'LText' alias for lazy 'Text'
 -- * 'LByteString' alias for lazy 'ByteString'
 -- * 'fromFoldable' to convert from 'Data.Foldable.Foldable' to an 'IsList' type
--- * 'convertList' to convert between two 'IsList' types. This function can be used instead of the 'toList' function
---   originally provided by the 'IsList' class.
+-- * 'convertList' to convert between two 'IsList' types.
+-- * 'asList' to convert from an 'IsList' type to a 'List'. This function is an
+--   alias for the 'toList' function from the 'IsList' class.
 -- * 'showT' and 'showS' are monomorphic 'show' functions.
 -- * '<>^' lifted composition
 -- * '.:' function composition
@@ -137,8 +138,9 @@
   , Intro.Trustworthy.IsList(
       Item
       , fromList
       -- , toList -- provided by Foldable
       )
+  , asList
   , convertList
   , fromFoldable
   , Data.List.break
@@ -276,8 +278,7 @@
   , Intro.Trustworthy.Hashable1
   , Intro.Trustworthy.Hashable2
 
-  -- ** DList and Seq
-  , Intro.Trustworthy.DList
+  -- ** Seq
   , Data.Sequence.Seq
 
   -- * Numeric types
@@ -608,9 +609,6 @@
   , GHC.Generics.Generic
   , GHC.Generics.Generic1
   , Data.Typeable.Typeable
-  , Control.DeepSeq.NFData
-  , Control.DeepSeq.NFData1
-  , Control.DeepSeq.NFData2
 
   -- * Type level
   , Data.Kind.Type
@@ -669,7 +667,6 @@
 import Text.Show (Show)
 import qualified Control.Applicative
 import qualified Control.Category
-import qualified Control.DeepSeq
 import qualified Control.Monad
 import qualified Control.Monad.Except
 import qualified Control.Monad.Extra
@@ -749,6 +746,12 @@
 convertList = fromList . toList
 {-# INLINE convertList #-}
 
+-- | The 'asList' function extracts a list of @Item a@ from the structure @a@.
+--   It should satisfy fromList . asList = id.
+asList :: (IsList a) => a -> [Item a]
+asList = Intro.Trustworthy.toList
+{-# INLINE asList #-}
+
 -- | A synonym for 'fmap'.
 --
 --   @map = 'fmap'@
@@ -927,3 +930,4 @@
 fail :: Control.Monad.Fail.MonadFail m => Text -> m a
 fail = Control.Monad.Fail.fail . convertString
 {-# INLINE fail #-}
+
@@ -137,8 +138,9 @@
       Item
       , fromList
-      -- , toList -- provided by Foldable
+      -- , toList -- renamed to asList
       )